==> owncloud-9.0.3.tgz: owncloud/apps/files_sharing/l10n/ca.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "La compartició entre servidors no està activada en aquest servidor",
    "Invalid or untrusted SSL certificate" : "El certificat SSL és invàlid o no és fiable",
    "Storage not valid" : "Emmagatzemament no valit",
    "Couldn't add remote share" : "No s'ha pogut afegir una compartició remota",
    "Shared with you" : "Us han compartit",
    "Shared with others" : "Heu compartit",
    "Shared by link" : "Compartit amb enllaç",
    "No shared links" : "no hi ha enllaços compartits",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Voleu afegir la compartició remota {nom} des de {owner}@{remote}?",
    "Remote share" : "Compartició remota",
    "Remote share password" : "Contrasenya de compartició remota",
    "Cancel" : "Cancel·la",
    "Add remote share" : "Afegeix compartició remota",
    "Invalid ownCloud url" : "La url d'ownCloud no és vàlida",
    "Shared by" : "Compartit per",
    "Sharing" : "Compartir",
    "A file or folder has been <strong>shared</strong>" : "S'ha <strong>compartit</strong> un fitxer o una carpeta",
    "You shared %1$s with %2$s" : "Has compartit %1$s amb %2$s",
    "You shared %1$s with group %2$s" : "has compartit %1$s amb el grup %2$s",
    "You shared %1$s via link" : "Heu compartit %1$s via enllaç",
    "%2$s shared %1$s with you" : "%2$s ha compartit %1$s amb tu",
    "Shares" : "Compartits",
    "This share is password-protected" : "Aquest compartit està protegit amb contrasenya",
    "The password is wrong. Try again." : "la contrasenya és incorrecta. Intenteu-ho de nou.",
    "Password" : "Contrasenya",
    "No entries found in this folder" : "No hi ha entrades en aquesta carpeta",
    "Name" : "Nom",
    "Share time" : "Temps de compartició",
    "Sorry, this link doesn’t seem to work anymore." : "Aquest enllaç sembla que no funciona.",
    "Reasons might be:" : "Les raons podrien ser:",
    "the item was removed" : "l'element ha estat eliminat",
    "the link expired" : "l'enllaç ha vençut",
    "sharing is disabled" : "s'ha desactivat la compartició",
    "For more info, please ask the person who sent this link." : "Per més informació contacteu amb qui us ha enviat l'enllaç.",
    "Add to your ownCloud" : "Afegiu a ownCloud",
    "Download" : "Baixa",
    "Download %s" : "Baixa %s",
    "Direct link" : "Enllaç directe",
    "Open documentation" : "Obre la documentació"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/ca.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "La compartició entre servidors no està activada en aquest servidor",
    "The mountpoint name contains invalid characters." : "El punt de muntatge conté caràcters invàlids.",
    "Not allowed to create a federated share with the same user server" : "No s'ha permés la creació d'un recurs compartit federat amb el mateix servidor de l'usuari",
    "Invalid or untrusted SSL certificate" : "El certificat SSL és invàlid o no és fiable",
    "Could not authenticate to remote share, password might be wrong" : "No s'ha pogut autenticar al recurs compartit remot, la contrasenya potser estigui equivocada",
    "Storage not valid" : "Emmagatzemament no valit",
    "Couldn't add remote share" : "No s'ha pogut afegir una compartició remota",
    "Shared with you" : "Us han compartit",
    "Shared with others" : "Heu compartit",
    "Shared by link" : "Compartit amb enllaç",
    "Uploading..." : "Pujant...",
    "Nothing shared with you yet" : "Encara no s'ha compartit res amb tu ",
    "No shared links" : "no hi ha enllaços compartits",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Voleu afegir la compartició remota {nom} des de {owner}@{remote}?",
    "Remote share" : "Compartició remota",
    "Remote share password" : "Contrasenya de compartició remota",
    "Cancel" : "Cancel·la",
    "Add remote share" : "Afegeix compartició remota",
    "Invalid ownCloud url" : "La url d'ownCloud no és vàlida",
    "Share" : "Compartir",
    "Shared by" : "Compartit per",
    "Sharing" : "Compartir",
    "A file or folder has been <strong>shared</strong>" : "S'ha <strong>compartit</strong> un fitxer o una carpeta",
    "You shared %1$s with %2$s" : "Has compartit %1$s amb %2$s",
    "You shared %1$s with group %2$s" : "has compartit %1$s amb el grup %2$s",
    "You shared %1$s via link" : "Heu compartit %1$s via enllaç",
    "%2$s shared %1$s with you" : "%2$s ha compartit %1$s amb tu",
    "Shares" : "Compartits",
    "This share is password-protected" : "Aquest compartit està protegit amb contrasenya",
    "The password is wrong. Try again." : "la contrasenya és incorrecta. Intenteu-ho de nou.",
    "Password" : "Contrasenya",
    "No entries found in this folder" : "No hi ha entrades en aquesta carpeta",
    "Name" : "Nom",
    "Share time" : "Temps de compartició",
    "Expiration date" : "Data de venciment",
    "Sorry, this link doesn’t seem to work anymore." : "Aquest enllaç sembla que no funciona.",
    "Reasons might be:" : "Les raons podrien ser:",
    "the item was removed" : "l'element ha estat eliminat",
    "the link expired" : "l'enllaç ha vençut",
    "sharing is disabled" : "s'ha desactivat la compartició",
    "For more info, please ask the person who sent this link." : "Per més informació contacteu amb qui us ha enviat l'enllaç.",
    "Add to your ownCloud" : "Afegiu a ownCloud",
    "Download" : "Baixa",
    "Download %s" : "Baixa %s",
    "Direct link" : "Enllaç directe"
},
"nplurals=2; plural=(n != 1);");
